pub struct WorkspaceBuildContext {
pub role: String,
pub profile: CanisterBuildProfile,
pub environment: String,
pub build_network: String,
pub workspace_root: PathBuf,
pub icp_root: PathBuf,
pub config_path: PathBuf,
pub local_replica: Option<LocalReplicaTarget>,
pub refresh_canonical_wasm_store_did: bool,
}Expand description
Exact authority for one canister artifact build.
Fields
role: Stringprofile: CanisterBuildProfileenvironment: Stringbuild_network: Stringworkspace_root: PathBuficp_root: PathBufconfig_path: PathBuflocal_replica: Option<LocalReplicaTarget>refresh_canonical_wasm_store_did: boolImplementations
Sourceimpl WorkspaceBuildContext
impl WorkspaceBuildContext
pub fn lines(&self) -> Vec<String>
Sourcepub fn with_profile(&self, profile: CanisterBuildProfile) -> Self
pub fn with_profile(&self, profile: CanisterBuildProfile) -> Self
Return a copy using a different Cargo profile for one child build.
Sourcepub fn with_role(&self, role: impl Into<String>) -> Self
pub fn with_role(&self, role: impl Into<String>) -> Self
Return a copy selecting another role in the same workspace authority.
Sourcepub fn apply_to_command(&self, command: &mut Command)
pub fn apply_to_command(&self, command: &mut Command)
Apply the exact Canic build authority to one child command.