write_bytes

Function write_bytes 

pub fn write_bytes(path: &Path, bytes: &[u8]) -> Result<()>
Durably replace one file through atomic publication of complete bytes.

Missing parent directories are created and durably linked before the file is published. Serialization must complete before calling this helper.