Module install_root

Module install_root 

Structs

InstallRootOptions
InstallRootOptions
InstallState
InstallState

Functions

discover_canic_config_choices
discover_current_canic_config_choices
Discover installable Canic config choices under the current workspace.
install_root
read_named_fleet_install_state
Read a named fleet state for the discovered current project.