pub enum InstallRootModuleVerificationError {
Missing,
Invalid {
observed: String,
},
Mismatch {
expected: String,
observed: String,
},
}Expand description
Typed failure while proving the module installed on the root Canister.
Variants
Missing
ICP status returned no installed module identity.
Invalid
ICP status returned a value that is not one 32-byte hexadecimal digest.
Mismatch
The installed module identity differs from the exact Wasm supplied to ICP.