pub struct InstallPhaseFailureError { /* private fields */ }Expand description
InstallPhaseFailureError
Host error preserving both the phase operation error and the independent failure-receipt persistence error. Owned by the install receipt adapter and exposed through root-install failures.
Implementations
Sourceimpl InstallPhaseFailureError
impl InstallPhaseFailureError
Sourcepub fn operation_error(&self) -> &(dyn Error + 'static)
pub fn operation_error(&self) -> &(dyn Error + 'static)
Return the original phase operation failure.
Sourcepub fn receipt_write_error(&self) -> &(dyn Error + 'static)
pub fn receipt_write_error(&self) -> &(dyn Error + 'static)
Return the independent failure-receipt persistence failure.