pub enum PackageValidationMode {
Build,
LockedBuild,
Passive,
}Expand description
PackageValidationMode
Cargo resolution fidelity used by the host-owned role evidence producer.
Variants
Build
Development evidence that may resolve and update dependencies.
LockedBuild
Build evidence that must use the existing lockfile but may fetch dependencies.
Passive
Read-only evidence that must use the existing lockfile and local cache.