Module install_root

Module install_root 

Structs

InstallRootBlockedError
InstallRootBlockedError
InstallRootError
Typed public failure for the root-install workflow.
InstallRootOptions
InstallRootOptions

Enums

ConfigDiscoveryError
ConfigDiscoveryError
InstallRootBlockKind
InstallRootBlockKind
InstallRootPhase
Stable phase in which a root install failed.

Functions

check_install_deployment_truth
Build the same read-only deployment truth check that can be used as a preflight for the current install inputs without mutating deployment state.
check_install_execution_preflight
Build a read-only execution preflight for the current install inputs.
current_canic_project_root
discover_canic_config_choices
discover_canic_project_root_from
discover_current_canic_config_choices
Discover installable Canic config choices under the current workspace.
discover_project_canic_config_choices
install_root
latest_deployment_truth_receipt_path_from_root
Find the latest persisted deployment-truth receipt for one exact Fleet.
project_app_roots
select_discovered_app_config_path
Select one config from a canonically admitted discovery result by app name.