Module install_root

Module install_root 

Structs

InstallRootBlockedError
InstallRootBlockedError
InstallRootOptions
InstallRootOptions
InstallState
InstallState
RegisterDeploymentStateOptions
RegisterDeploymentStateOptions
VerifyDeploymentRootOptions
VerifyDeploymentRootOptions

Enums

InstallRootBlockKind
InstallRootBlockKind
InstallStateError
Typed failure while locating, validating, decoding, or persisting install state.
RootVerificationStatus
RootVerificationStatus

Functions

check_install_deployment_truth
Build the same read-only deployment truth check that can be used as a preflight for the current install inputs without mutating deployment state.
check_install_execution_preflight
Build a read-only execution preflight for the current install inputs.
current_canic_project_root
discover_canic_config_choices
discover_canic_project_root_from
discover_current_canic_config_choices
Discover installable Canic config choices under the current workspace.
discover_project_canic_config_choices
install_root
latest_deployment_truth_receipt_path_from_root
Find the latest persisted deployment-truth receipt for one local deployment target.
project_fleet_roots
read_named_deployment_install_state
Read deployment-target install state for the discovered current project.
read_named_deployment_install_state_from_root
Read deployment-target install state for an explicit ICP project root.
register_deployment_state
Register minimal local deployment-target state for an existing root canister.
verify_registered_deployment_root
Promote an explicitly registered deployment root from not_verified to verified using bound deployment-truth evidence.