Structs
- Install
Root Options - InstallRootOptions
- Install
State - InstallState
- Register
Deployment State Options - RegisterDeploymentStateOptions
- Verify
Deployment Root Options - VerifyDeploymentRootOptions
Enums
- Root
Verification Status - RootVerificationStatus
Functions
- check_
install_ deployment_ truth - Build the same read-only deployment truth check that can be used as a preflight for the current install inputs without mutating deployment state.
- check_
install_ execution_ preflight - Build a read-only execution preflight for the current install inputs.
- current_
canic_ project_ root - discover_
canic_ config_ choices - discover_
canic_ project_ root_ from - discover_
current_ canic_ config_ choices - Discover installable Canic config choices under the current workspace.
- discover_
project_ canic_ config_ choices - install_
root - latest_
deployment_ truth_ receipt_ path_ from_ root - Find the latest persisted deployment-truth receipt for one local deployment target.
- project_
fleet_ roots - read_
named_ deployment_ install_ state - Read deployment-target install state for the discovered current project.
- read_
named_ deployment_ install_ state_ from_ root - Read deployment-target install state for an explicit ICP project root.
- register_
deployment_ state - Register minimal local deployment-target state for an existing root canister.
- verify_
registered_ deployment_ root - Promote an explicitly registered deployment root from
not_verifiedtoverifiedusing bound deployment-truth evidence.