Module install_root

Module install_root 

Structs

InstallRootOptions
InstallRootOptions
InstallState
InstallState

Functions

check_install_deployment_truth
Build the same read-only deployment truth check that can be used as a preflight for the current install inputs without mutating deployment state.
current_canic_project_root
discover_canic_config_choices
discover_canic_project_root_from
discover_current_canic_config_choices
Discover installable Canic config choices under the current workspace.
discover_project_canic_config_choices
install_root
latest_deployment_truth_receipt_path_from_root
Find the latest persisted deployment-truth receipt for one local fleet.
project_fleet_roots
read_named_fleet_install_state
Read a named fleet state for the discovered current project.
read_named_fleet_install_state_from_root
Read a named fleet state for an explicit ICP project root.