Structs
- Install
Root Options - InstallRootOptions
- Install
State - InstallState
Functions
- check_
install_ deployment_ truth - Build the same read-only deployment truth check that can be used as a preflight for the current install inputs without mutating deployment state.
- current_
canic_ project_ root - discover_
canic_ config_ choices - discover_
canic_ project_ root_ from - discover_
current_ canic_ config_ choices - Discover installable Canic config choices under the current workspace.
- discover_
project_ canic_ config_ choices - install_
root - latest_
deployment_ truth_ receipt_ path_ from_ root - Find the latest persisted deployment-truth receipt for one local fleet.
- project_
fleet_ roots - read_
named_ fleet_ install_ state - Read a named fleet state for the discovered current project.
- read_
named_ fleet_ install_ state_ from_ root - Read a named fleet state for an explicit ICP project root.