pub struct AppConfigSnapshot { /* private fields */ }Expand description
One immutable, validated view of an App configuration file.
Commands that need several projections should load this once so every decision is derived from the same bytes on disk.
Implementations
Sourceimpl AppConfigSnapshot
impl AppConfigSnapshot
pub fn load(path: &Path) -> Result<Self, AppConfigError>
pub const fn model(&self) -> &ConfigModel
Sourcepub const fn component_topology(&self) -> &ComponentTopology
pub const fn component_topology(&self) -> &ComponentTopology
Return the immutable compiled topology derived from the same config bytes.
pub const fn app_id(&self) -> &str
pub fn deployable_roles(&self) -> Vec<String>
pub fn bootstrap_roles(&self) -> Vec<String>
pub fn local_root_create_cycles(&self) -> Result<u128, AppConfigError>
pub fn controllers(&self) -> Vec<String>
pub fn pool_expectations(&self) -> Vec<ConfiguredPoolExpectation>
pub fn role_lifecycle(&self) -> Vec<ConfiguredRoleLifecycle>
pub fn role_kinds(&self) -> BTreeMap<String, String>
pub fn role_capabilities( &self, ) -> Result<BTreeMap<String, Vec<String>>, AppConfigError>
pub fn role_auto_create(&self) -> BTreeSet<String>
pub fn role_topups(&self) -> BTreeMap<String, String>
pub fn role_metrics_profiles(&self) -> BTreeMap<String, String>
pub fn role_details(&self) -> BTreeMap<String, Vec<String>>